aboutsummaryrefslogtreecommitdiffstats
path: root/host/apps/omap_debug/usrp-e-spi.c
diff options
context:
space:
mode:
authorroot <root@usrp1-e.(none)>2010-03-25 17:42:36 +0000
committerroot <root@usrp1-e.(none)>2010-03-25 17:42:36 +0000
commit28e5e0740a8fc3c7233a1bd5cc6bbc897c586da6 (patch)
tree8a5daa7b11fbd4f289d7875d66238626441541f4 /host/apps/omap_debug/usrp-e-spi.c
parent4f5cd64188c7e2b5490d910d5e86301c053960ea (diff)
downloaduhd-28e5e0740a8fc3c7233a1bd5cc6bbc897c586da6.tar.gz
uhd-28e5e0740a8fc3c7233a1bd5cc6bbc897c586da6.tar.bz2
uhd-28e5e0740a8fc3c7233a1bd5cc6bbc897c586da6.zip
Updates for header file change from usrp1_e.h to usrp_e.h.
Diffstat (limited to 'host/apps/omap_debug/usrp-e-spi.c')
-rw-r--r--host/apps/omap_debug/usrp-e-spi.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/host/apps/omap_debug/usrp-e-spi.c b/host/apps/omap_debug/usrp-e-spi.c
index e10e72b80..1af47b172 100644
--- a/host/apps/omap_debug/usrp-e-spi.c
+++ b/host/apps/omap_debug/usrp-e-spi.c
@@ -4,9 +4,9 @@
#include <fcntl.h>
#include <sys/ioctl.h>
#include "usrp1_e.h"
// Usage: usrp1_e_spi w|rb slave data
int main(int argc, char *argv[])
{
@@ -14,14 +14,14 @@ int main(int argc, char *argv[])
struct usrp_e_spi spi_dat;
if (argc < 4) {
- printf("Usage: usrp1_e_spi w|rb slave data\n");
+ printf("Usage: usrp_e_spi w|rb slave data\n");
exit(-1);
}
slave = atoi(argv[2]);
data = atoi(argv[3]);
- fp = open("/dev/usrp1_e0", O_RDWR);
+ fp = open("/dev/usrp_e0", O_RDWR);
printf("fp = %d\n", fp);
spi_dat.slave = slave;
@@ -4,9 +4,9 @@
#include <fcntl.h>
#include <sys/ioctl.h>
-#include "usrp1_e.h"
+#include "usrp_e.h"
-// Usage: usrp1_e_spi w|rb slave data
+// Usage: usrp_e_spi w|rb slave data
int main(int argc, char *argv[])
{